Convenience Functions using NumPy Arrays
========================================

.. currentmodule:: sounddevice

.. topic:: Overview

   .. autosummary::
      :nosignatures:
   
      play
      rec
      playrec
      wait
      stop
      get_status
      get_stream

.. autofunction:: play

.. autofunction:: rec

.. autofunction:: playrec

.. autofunction:: wait

.. autofunction:: stop

.. autofunction:: get_status

.. autofunction:: get_stream
